Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1752)

Unified Diff: ash/common/accelerators/accelerator_controller.cc

Issue 2739553005: Moves maintaining root_window_for_new_windows_ to Shell (Closed)
Patch Set: remove ash:: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ash/common/accelerators/exit_warning_handler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/accelerators/accelerator_controller.cc
diff --git a/ash/common/accelerators/accelerator_controller.cc b/ash/common/accelerators/accelerator_controller.cc
index 52e33dd9981ed584f1f5d09879d93c634efba0bb..46abdd953c7f59d78ed835912256131bbe1b85ec 100644
--- a/ash/common/accelerators/accelerator_controller.cc
+++ b/ash/common/accelerators/accelerator_controller.cc
@@ -41,6 +41,7 @@
#include "ash/common/wm_window.h"
#include "ash/resources/vector_icons/vector_icons.h"
#include "ash/root_window_controller.h"
+#include "ash/shell.h"
#include "ash/strings/grit/ash_strings.h"
#include "base/metrics/histogram_macros.h"
#include "base/metrics/user_metrics.h"
@@ -115,7 +116,7 @@ void HandleRotatePaneFocus(FocusCycler::Direction direction) {
void HandleFocusShelf() {
base::RecordAction(UserMetricsAction("Accel_Focus_Shelf"));
// TODO(jamescook): Should this be GetRootWindowForNewWindows()?
WmShelf* shelf = WmShelf::ForWindow(WmShell::Get()->GetPrimaryRootWindow());
WmShell::Get()->focus_cycler()->FocusWidget(shelf->shelf_widget());
}
@@ -211,7 +212,7 @@ void HandleShowKeyboardOverlay() {
}
bool CanHandleShowMessageCenterBubble() {
- WmWindow* target_root = WmShell::Get()->GetRootWindowForNewWindows();
+ WmWindow* target_root = Shell::GetWmRootWindowForNewWindows();
StatusAreaWidget* status_area_widget =
WmShelf::ForWindow(target_root)->shelf_widget()->status_area_widget();
return status_area_widget &&
@@ -220,7 +221,7 @@ bool CanHandleShowMessageCenterBubble() {
void HandleShowMessageCenterBubble() {
base::RecordAction(UserMetricsAction("Accel_Show_Message_Center_Bubble"));
- WmWindow* target_root = WmShell::Get()->GetRootWindowForNewWindows();
+ WmWindow* target_root = Shell::GetWmRootWindowForNewWindows();
StatusAreaWidget* status_area_widget =
WmShelf::ForWindow(target_root)->shelf_widget()->status_area_widget();
if (status_area_widget) {
@@ -394,7 +395,7 @@ void HandleShowStylusTools() {
base::RecordAction(UserMetricsAction("Accel_Show_Stylus_Tools"));
RootWindowController* root_window_controller =
- WmShell::Get()->GetRootWindowForNewWindows()->GetRootWindowController();
+ Shell::GetWmRootWindowForNewWindows()->GetRootWindowController();
PaletteTray* palette_tray =
root_window_controller->GetShelf()->GetStatusAreaWidget()->palette_tray();
palette_tray->ShowPalette();
@@ -115,7 +116,7 @@ void HandleRotatePaneFocus(FocusCycler::Direction direction) {
void HandleFocusShelf() {
base::RecordAction(UserMetricsAction("Accel_Focus_Shelf"));
- // TODO(jamescook): Should this be GetRootWindowForNewWindows()?
+ // TODO(jamescook): Should this be GetWmRootWindowForNewWindows()?
WmShelf* shelf = WmShelf::ForWindow(WmShell::Get()->GetPrimaryRootWindow());
WmShell::Get()->focus_cycler()->FocusWidget(shelf->shelf_widget());
« no previous file with comments | « no previous file | ash/common/accelerators/exit_warning_handler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698